#
# spec file for package remind
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           remind
Version:        5.3.2
Release:        1.2
%define tar_version 05.03.02
Summary:        A sophisticated calendar and alarm program
License:        GPL-2.0-only
Group:          Productivity/Office/Organizers
URL:            https://dianne.skoll.ca/projects/remind/
Source0:        %{name}-%{tar_version}.tar.gz
Source100:      %{name}-rpmlintrc
BuildRequires:  perl
BuildRequires:  perl-Cairo
BuildRequires:  perl-Getopt-Long-Descriptive
BuildRequires:  perl-JSON-MaybeXS
BuildRequires:  perl-Pango

Requires:       perl
Requires:       perl-Cairo
Requires:       perl-Getopt-Long-Descriptive
Requires:       perl-JSON-Any
Requires:       perl-Pango
Requires:       tcllib

%description
Remind is a sophisticated calendar and alarm program.
It includes the following features:

* A sophisticated scripting language and intelligent
  handling of exceptions and holidays.
* Plain-text, PostScript and HTML output.
* Timed reminders and pop-up alarms.
* A friendly graphical front-end for people who don't
  want to learn the scripting language.
* Facilities for both the Gregorian and Hebrew calendars.
* Support for 12 different languages.

%prep
%setup -q -n %{name}-%{tar_version}

%build
CFLAGS="%{optflags}" ./configure --disable-perl-build-artifacts --prefix=%{_prefix}
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install

##%%check
##make test

%files
%defattr(-,root,root,-)
%doc %{_mandir}/man1/rem.1%{ext_man}
%doc %{_mandir}/man1/rem2html.1%{ext_man}
%doc %{_mandir}/man1/rem2ps.1%{ext_man}
%doc %{_mandir}/man1/rem2pdf.1%{ext_man}
%doc %{_mandir}/man1/remind.1%{ext_man}
%doc %{_mandir}/man1/tkremind.1%{ext_man}
%doc %{_mandir}/man3/Remind::PDF.3pm%{ext_man}
%doc %{_mandir}/man3/Remind::PDF::Entry.3pm%{ext_man}

%{_bindir}/rem
%attr(0755,root,root) %{_bindir}/rem2html
%attr(0755,root,root) %{_bindir}/rem2pdf
%attr(0755,root,root) %{_bindir}/rem2ps
%attr(0755,root,root) %{_bindir}/remind
%attr(0755,root,root) %{_bindir}/tkremind
%attr(0755,root,root) %{perl_vendorlib}/Remind/

%dir /usr/share/remind/
%dir /usr/share/remind/holidays
%dir /usr/share/remind/lang
%dir /usr/share/remind/site
/usr/share/remind/ansitext.rem

/usr/share/remind/holidays/README
/usr/share/remind/holidays/ad.rem
%dir /usr/share/remind/holidays/ad
/usr/share/remind/holidays/ad/02.rem
/usr/share/remind/holidays/ad/03.rem
/usr/share/remind/holidays/ad/04.rem
/usr/share/remind/holidays/ad/05.rem
/usr/share/remind/holidays/ad/06.rem
/usr/share/remind/holidays/ad/07.rem
/usr/share/remind/holidays/ad/08.rem
/usr/share/remind/holidays/ae.rem
/usr/share/remind/holidays/al.rem
/usr/share/remind/holidays/am.rem
/usr/share/remind/holidays/ao.rem
/usr/share/remind/holidays/ar.rem
/usr/share/remind/holidays/as.rem
/usr/share/remind/holidays/at.rem
%dir /usr/share/remind/holidays/at
/usr/share/remind/holidays/at/1.rem
/usr/share/remind/holidays/at/2.rem
/usr/share/remind/holidays/at/3.rem
/usr/share/remind/holidays/at/4.rem
/usr/share/remind/holidays/at/5.rem
/usr/share/remind/holidays/at/6.rem
/usr/share/remind/holidays/at/7.rem
/usr/share/remind/holidays/at/8.rem
/usr/share/remind/holidays/at/9.rem
/usr/share/remind/holidays/au.rem
%dir /usr/share/remind/holidays/au
/usr/share/remind/holidays/au/act.rem
/usr/share/remind/holidays/au/nsw.rem
/usr/share/remind/holidays/au/nt.rem
/usr/share/remind/holidays/au/qld.rem
/usr/share/remind/holidays/au/sa.rem
/usr/share/remind/holidays/au/tas.rem
/usr/share/remind/holidays/au/vic.rem
/usr/share/remind/holidays/au/wa.rem
/usr/share/remind/holidays/aw.rem
/usr/share/remind/holidays/az.rem
/usr/share/remind/holidays/ba.rem
%dir /usr/share/remind/holidays/ba
/usr/share/remind/holidays/ba/bih.rem
/usr/share/remind/holidays/ba/brc.rem
/usr/share/remind/holidays/ba/srp.rem
/usr/share/remind/holidays/bb.rem
/usr/share/remind/holidays/bd.rem
/usr/share/remind/holidays/be.rem
/usr/share/remind/holidays/bf.rem
/usr/share/remind/holidays/bg.rem
/usr/share/remind/holidays/bh.rem
/usr/share/remind/holidays/bi.rem
/usr/share/remind/holidays/bn.rem
/usr/share/remind/holidays/bo.rem
%dir /usr/share/remind/holidays/bo
/usr/share/remind/holidays/bo/b.rem
/usr/share/remind/holidays/bo/c.rem
/usr/share/remind/holidays/bo/h.rem
/usr/share/remind/holidays/bo/l.rem
/usr/share/remind/holidays/bo/n.rem
/usr/share/remind/holidays/bo/o.rem
/usr/share/remind/holidays/bo/p.rem
/usr/share/remind/holidays/bo/s.rem
/usr/share/remind/holidays/bo/t.rem
/usr/share/remind/holidays/br.rem
%dir /usr/share/remind/holidays/br
/usr/share/remind/holidays/br/ac.rem
/usr/share/remind/holidays/br/al.rem
/usr/share/remind/holidays/br/am.rem
/usr/share/remind/holidays/br/ap.rem
/usr/share/remind/holidays/br/ba.rem
/usr/share/remind/holidays/br/ce.rem
/usr/share/remind/holidays/br/df.rem
/usr/share/remind/holidays/br/es.rem
/usr/share/remind/holidays/br/go.rem
/usr/share/remind/holidays/br/ma.rem
/usr/share/remind/holidays/br/mg.rem
/usr/share/remind/holidays/br/ms.rem
/usr/share/remind/holidays/br/pa.rem
/usr/share/remind/holidays/br/pb.rem
/usr/share/remind/holidays/br/pe.rem
/usr/share/remind/holidays/br/pi.rem
/usr/share/remind/holidays/br/pr.rem
/usr/share/remind/holidays/br/rj.rem
/usr/share/remind/holidays/br/rn.rem
/usr/share/remind/holidays/br/ro.rem
/usr/share/remind/holidays/br/rr.rem
/usr/share/remind/holidays/br/rs.rem
/usr/share/remind/holidays/br/sc.rem
/usr/share/remind/holidays/br/se.rem
/usr/share/remind/holidays/br/sp.rem
/usr/share/remind/holidays/br/to.rem
/usr/share/remind/holidays/bs.rem
/usr/share/remind/holidays/bw.rem
/usr/share/remind/holidays/by.rem
/usr/share/remind/holidays/bz.rem
/usr/share/remind/holidays/ca.rem
%dir /usr/share/remind/holidays/ca
/usr/share/remind/holidays/ca/ab.rem
/usr/share/remind/holidays/ca/bc.rem
/usr/share/remind/holidays/ca/mb.rem
/usr/share/remind/holidays/ca/nb.rem
/usr/share/remind/holidays/ca/nl.rem
/usr/share/remind/holidays/ca/ns.rem
/usr/share/remind/holidays/ca/nt.rem
/usr/share/remind/holidays/ca/nu.rem
/usr/share/remind/holidays/ca/on.rem
/usr/share/remind/holidays/ca/pe.rem
/usr/share/remind/holidays/ca/qc.rem
/usr/share/remind/holidays/ca/sk.rem
/usr/share/remind/holidays/ca/yt.rem
/usr/share/remind/holidays/cg.rem
/usr/share/remind/holidays/ch.rem
%dir /usr/share/remind/holidays/ch
/usr/share/remind/holidays/chinese-new-year.rem
/usr/share/remind/holidays/ch/ag.rem
/usr/share/remind/holidays/ch/ai.rem
/usr/share/remind/holidays/ch/ar.rem
/usr/share/remind/holidays/ch/be.rem
/usr/share/remind/holidays/ch/bl.rem
/usr/share/remind/holidays/ch/bs.rem
/usr/share/remind/holidays/ch/fr.rem
/usr/share/remind/holidays/ch/ge.rem
/usr/share/remind/holidays/ch/gl.rem
/usr/share/remind/holidays/ch/gr.rem
/usr/share/remind/holidays/ch/ju.rem
/usr/share/remind/holidays/ch/lu.rem
/usr/share/remind/holidays/ch/ne.rem
/usr/share/remind/holidays/ch/nw.rem
/usr/share/remind/holidays/ch/ow.rem
/usr/share/remind/holidays/ch/sg.rem
/usr/share/remind/holidays/ch/sh.rem
/usr/share/remind/holidays/ch/so.rem
/usr/share/remind/holidays/ch/sz.rem
/usr/share/remind/holidays/ch/tg.rem
/usr/share/remind/holidays/ch/ti.rem
/usr/share/remind/holidays/ch/ur.rem
/usr/share/remind/holidays/ch/vd.rem
/usr/share/remind/holidays/ch/vs.rem
/usr/share/remind/holidays/ch/zg.rem
/usr/share/remind/holidays/ch/zh.rem
/usr/share/remind/holidays/cl.rem
%dir /usr/share/remind/holidays/cl
/usr/share/remind/holidays/cl/ap.rem
/usr/share/remind/holidays/cl/nb.rem
/usr/share/remind/holidays/cm.rem
/usr/share/remind/holidays/co.rem
/usr/share/remind/holidays/cr.rem
/usr/share/remind/holidays/cu.rem
/usr/share/remind/holidays/cw.rem
/usr/share/remind/holidays/cy.rem
/usr/share/remind/holidays/cz.rem
/usr/share/remind/holidays/de.rem
%dir /usr/share/remind/holidays/de
/usr/share/remind/holidays/de/bb.rem
/usr/share/remind/holidays/de/be.rem
/usr/share/remind/holidays/de/bw.rem
/usr/share/remind/holidays/de/by.rem
/usr/share/remind/holidays/de/hb.rem
/usr/share/remind/holidays/de/he.rem
/usr/share/remind/holidays/de/hh.rem
/usr/share/remind/holidays/de/mv.rem
/usr/share/remind/holidays/de/ni.rem
/usr/share/remind/holidays/de/nw.rem
/usr/share/remind/holidays/de/rp.rem
/usr/share/remind/holidays/de/sh.rem
/usr/share/remind/holidays/de/sl.rem
/usr/share/remind/holidays/de/sn.rem
/usr/share/remind/holidays/de/st.rem
/usr/share/remind/holidays/de/th.rem
/usr/share/remind/holidays/discordian.rem
/usr/share/remind/holidays/dj.rem
/usr/share/remind/holidays/dk.rem
/usr/share/remind/holidays/dm.rem
/usr/share/remind/holidays/do.rem
/usr/share/remind/holidays/dz.rem
/usr/share/remind/holidays/ec.rem
/usr/share/remind/holidays/ee.rem
/usr/share/remind/holidays/eg.rem
/usr/share/remind/holidays/es.rem
%dir /usr/share/remind/holidays/es
/usr/share/remind/holidays/es/an.rem
/usr/share/remind/holidays/es/ar.rem
/usr/share/remind/holidays/es/as.rem
/usr/share/remind/holidays/es/cb.rem
/usr/share/remind/holidays/es/ce.rem
/usr/share/remind/holidays/es/cl.rem
/usr/share/remind/holidays/es/cm.rem
/usr/share/remind/holidays/es/cn.rem
/usr/share/remind/holidays/es/ct.rem
/usr/share/remind/holidays/es/ex.rem
/usr/share/remind/holidays/es/ga.rem
/usr/share/remind/holidays/es/ib.rem
/usr/share/remind/holidays/es/mc.rem
/usr/share/remind/holidays/es/md.rem
/usr/share/remind/holidays/es/ml.rem
/usr/share/remind/holidays/es/nc.rem
/usr/share/remind/holidays/es/pv.rem
/usr/share/remind/holidays/es/ri.rem
/usr/share/remind/holidays/es/vc.rem
/usr/share/remind/holidays/et.rem
/usr/share/remind/holidays/fi.rem
/usr/share/remind/holidays/fr.rem
%dir /usr/share/remind/holidays/fr
/usr/share/remind/holidays/fr/bl.rem
/usr/share/remind/holidays/fr/ges.rem
/usr/share/remind/holidays/fr/gp.rem
/usr/share/remind/holidays/fr/gy.rem
/usr/share/remind/holidays/fr/mf.rem
/usr/share/remind/holidays/fr/mq.rem
/usr/share/remind/holidays/fr/nc.rem
/usr/share/remind/holidays/fr/pf.rem
/usr/share/remind/holidays/fr/re.rem
/usr/share/remind/holidays/fr/wf.rem
/usr/share/remind/holidays/fr/yt.rem
/usr/share/remind/holidays/ga.rem
/usr/share/remind/holidays/gb.rem
%dir /usr/share/remind/holidays/gb
/usr/share/remind/holidays/gb/eng.rem
/usr/share/remind/holidays/gb/nir.rem
/usr/share/remind/holidays/gb/sct.rem
/usr/share/remind/holidays/gb/wls.rem
/usr/share/remind/holidays/ge.rem
/usr/share/remind/holidays/gh.rem
/usr/share/remind/holidays/gl.rem
/usr/share/remind/holidays/gr.rem
/usr/share/remind/holidays/gt.rem
/usr/share/remind/holidays/gu.rem
/usr/share/remind/holidays/hk.rem
/usr/share/remind/holidays/hn.rem
/usr/share/remind/holidays/hr.rem
/usr/share/remind/holidays/ht.rem
/usr/share/remind/holidays/hu.rem
/usr/share/remind/holidays/id.rem
/usr/share/remind/holidays/ie.rem
/usr/share/remind/holidays/im.rem
/usr/share/remind/holidays/in.rem
%dir /usr/share/remind/holidays/in
/usr/share/remind/holidays/in/ap.rem
/usr/share/remind/holidays/in/as.rem
/usr/share/remind/holidays/in/br.rem
/usr/share/remind/holidays/in/cg.rem
/usr/share/remind/holidays/in/gj.rem
/usr/share/remind/holidays/in/hr.rem
/usr/share/remind/holidays/in/ka.rem
/usr/share/remind/holidays/in/kl.rem
/usr/share/remind/holidays/in/mh.rem
/usr/share/remind/holidays/in/mp.rem
/usr/share/remind/holidays/in/od.rem
/usr/share/remind/holidays/in/rj.rem
/usr/share/remind/holidays/in/sk.rem
/usr/share/remind/holidays/in/tn.rem
/usr/share/remind/holidays/in/ts.rem
/usr/share/remind/holidays/in/uk.rem
/usr/share/remind/holidays/in/up.rem
/usr/share/remind/holidays/in/wb.rem
/usr/share/remind/holidays/is.rem
/usr/share/remind/holidays/it.rem
%dir /usr/share/remind/holidays/it
/usr/share/remind/holidays/it/ag.rem
/usr/share/remind/holidays/it/al.rem
/usr/share/remind/holidays/it/an.rem
/usr/share/remind/holidays/it/andria.rem
/usr/share/remind/holidays/it/ao.rem
/usr/share/remind/holidays/it/ap.rem
/usr/share/remind/holidays/it/aq.rem
/usr/share/remind/holidays/it/ar.rem
/usr/share/remind/holidays/it/at.rem
/usr/share/remind/holidays/it/av.rem
/usr/share/remind/holidays/it/ba.rem
/usr/share/remind/holidays/it/barletta.rem
/usr/share/remind/holidays/it/bg.rem
/usr/share/remind/holidays/it/bl.rem
/usr/share/remind/holidays/it/bn.rem
/usr/share/remind/holidays/it/bo.rem
/usr/share/remind/holidays/it/br.rem
/usr/share/remind/holidays/it/bs.rem
/usr/share/remind/holidays/it/bt.rem
/usr/share/remind/holidays/it/bz.rem
/usr/share/remind/holidays/it/ca.rem
/usr/share/remind/holidays/it/cb.rem
/usr/share/remind/holidays/it/ce.rem
/usr/share/remind/holidays/it/cesena.rem
/usr/share/remind/holidays/it/ch.rem
/usr/share/remind/holidays/it/cl.rem
/usr/share/remind/holidays/it/cn.rem
/usr/share/remind/holidays/it/co.rem
/usr/share/remind/holidays/it/cr.rem
/usr/share/remind/holidays/it/cs.rem
/usr/share/remind/holidays/it/ct.rem
/usr/share/remind/holidays/it/cz.rem
/usr/share/remind/holidays/it/en.rem
/usr/share/remind/holidays/it/fc.rem
/usr/share/remind/holidays/it/fe.rem
/usr/share/remind/holidays/it/fg.rem
/usr/share/remind/holidays/it/fi.rem
/usr/share/remind/holidays/it/fm.rem
/usr/share/remind/holidays/it/forli.rem
/usr/share/remind/holidays/it/fr.rem
/usr/share/remind/holidays/it/ge.rem
/usr/share/remind/holidays/it/go.rem
/usr/share/remind/holidays/it/gr.rem
/usr/share/remind/holidays/it/im.rem
/usr/share/remind/holidays/it/is.rem
/usr/share/remind/holidays/it/kr.rem
/usr/share/remind/holidays/it/lc.rem
/usr/share/remind/holidays/it/le.rem
/usr/share/remind/holidays/it/li.rem
/usr/share/remind/holidays/it/lo.rem
/usr/share/remind/holidays/it/lt.rem
/usr/share/remind/holidays/it/lu.rem
/usr/share/remind/holidays/it/mb.rem
/usr/share/remind/holidays/it/mc.rem
/usr/share/remind/holidays/it/me.rem
/usr/share/remind/holidays/it/mi.rem
/usr/share/remind/holidays/it/mn.rem
/usr/share/remind/holidays/it/mo.rem
/usr/share/remind/holidays/it/ms.rem
/usr/share/remind/holidays/it/mt.rem
/usr/share/remind/holidays/it/na.rem
/usr/share/remind/holidays/it/no.rem
/usr/share/remind/holidays/it/nu.rem
/usr/share/remind/holidays/it/or.rem
/usr/share/remind/holidays/it/pa.rem
/usr/share/remind/holidays/it/pc.rem
/usr/share/remind/holidays/it/pd.rem
/usr/share/remind/holidays/it/pe.rem
/usr/share/remind/holidays/it/pesaro.rem
/usr/share/remind/holidays/it/pg.rem
/usr/share/remind/holidays/it/pi.rem
/usr/share/remind/holidays/it/pn.rem
/usr/share/remind/holidays/it/pr.rem
/usr/share/remind/holidays/it/pt.rem
/usr/share/remind/holidays/it/pu.rem
/usr/share/remind/holidays/it/pv.rem
/usr/share/remind/holidays/it/pz.rem
/usr/share/remind/holidays/it/ra.rem
/usr/share/remind/holidays/it/rc.rem
/usr/share/remind/holidays/it/re.rem
/usr/share/remind/holidays/it/rg.rem
/usr/share/remind/holidays/it/ri.rem
/usr/share/remind/holidays/it/rm.rem
/usr/share/remind/holidays/it/rn.rem
/usr/share/remind/holidays/it/ro.rem
/usr/share/remind/holidays/it/sa.rem
/usr/share/remind/holidays/it/si.rem
/usr/share/remind/holidays/it/so.rem
/usr/share/remind/holidays/it/sp.rem
/usr/share/remind/holidays/it/sr.rem
/usr/share/remind/holidays/it/ss.rem
/usr/share/remind/holidays/it/su.rem
/usr/share/remind/holidays/it/sv.rem
/usr/share/remind/holidays/it/ta.rem
/usr/share/remind/holidays/it/te.rem
/usr/share/remind/holidays/it/tn.rem
/usr/share/remind/holidays/it/to.rem
/usr/share/remind/holidays/it/tp.rem
/usr/share/remind/holidays/it/tr.rem
/usr/share/remind/holidays/it/trani.rem
/usr/share/remind/holidays/it/ts.rem
/usr/share/remind/holidays/it/tv.rem
/usr/share/remind/holidays/it/ud.rem
/usr/share/remind/holidays/it/urbino.rem
/usr/share/remind/holidays/it/va.rem
/usr/share/remind/holidays/it/vb.rem
/usr/share/remind/holidays/it/vc.rem
/usr/share/remind/holidays/it/ve.rem
/usr/share/remind/holidays/it/vi.rem
/usr/share/remind/holidays/it/vr.rem
/usr/share/remind/holidays/it/vt.rem
/usr/share/remind/holidays/it/vv.rem
/usr/share/remind/holidays/je.rem
/usr/share/remind/holidays/jewish.rem
/usr/share/remind/holidays/jm.rem
/usr/share/remind/holidays/jo.rem
/usr/share/remind/holidays/jp.rem
/usr/share/remind/holidays/ke.rem
/usr/share/remind/holidays/kg.rem
/usr/share/remind/holidays/kh.rem
/usr/share/remind/holidays/kn.rem
/usr/share/remind/holidays/kr.rem
/usr/share/remind/holidays/kw.rem
/usr/share/remind/holidays/kz.rem
/usr/share/remind/holidays/la.rem
%dir /usr/share/remind/holidays/lgbtq
/usr/share/remind/holidays/lgbtq.rem
/usr/share/remind/holidays/lgbtq/au.rem
/usr/share/remind/holidays/lgbtq/br.rem
/usr/share/remind/holidays/lgbtq/ca.rem
/usr/share/remind/holidays/lgbtq/cl.rem
/usr/share/remind/holidays/lgbtq/ie.rem
/usr/share/remind/holidays/lgbtq/in.rem
/usr/share/remind/holidays/lgbtq/nl.rem
/usr/share/remind/holidays/lgbtq/ua.rem
/usr/share/remind/holidays/lgbtq/uk.rem
/usr/share/remind/holidays/lgbtq/us.rem
/usr/share/remind/holidays/li.rem
/usr/share/remind/holidays/ls.rem
/usr/share/remind/holidays/lt.rem
/usr/share/remind/holidays/lu.rem
/usr/share/remind/holidays/lv.rem
/usr/share/remind/holidays/ma.rem
/usr/share/remind/holidays/mc.rem
/usr/share/remind/holidays/md.rem
/usr/share/remind/holidays/me.rem
/usr/share/remind/holidays/mg.rem
/usr/share/remind/holidays/mh.rem
/usr/share/remind/holidays/mk.rem
/usr/share/remind/holidays/mp.rem
/usr/share/remind/holidays/mr.rem
/usr/share/remind/holidays/mt.rem
/usr/share/remind/holidays/mv.rem
/usr/share/remind/holidays/mw.rem
/usr/share/remind/holidays/mx.rem
/usr/share/remind/holidays/my.rem
%dir /usr/share/remind/holidays/my
/usr/share/remind/holidays/my/01.rem
/usr/share/remind/holidays/my/02.rem
/usr/share/remind/holidays/my/03.rem
/usr/share/remind/holidays/my/04.rem
/usr/share/remind/holidays/my/05.rem
/usr/share/remind/holidays/my/06.rem
/usr/share/remind/holidays/my/07.rem
/usr/share/remind/holidays/my/08.rem
/usr/share/remind/holidays/my/09.rem
/usr/share/remind/holidays/my/10.rem
/usr/share/remind/holidays/my/11.rem
/usr/share/remind/holidays/my/12.rem
/usr/share/remind/holidays/my/13.rem
/usr/share/remind/holidays/my/14.rem
/usr/share/remind/holidays/my/15.rem
/usr/share/remind/holidays/my/16.rem
/usr/share/remind/holidays/mz.rem
/usr/share/remind/holidays/na.rem
/usr/share/remind/holidays/ng.rem
/usr/share/remind/holidays/ni.rem
%dir /usr/share/remind/holidays/ni
/usr/share/remind/holidays/ni/mn.rem
/usr/share/remind/holidays/nl.rem
/usr/share/remind/holidays/no.rem
/usr/share/remind/holidays/nz.rem
%dir /usr/share/remind/holidays/nz
/usr/share/remind/holidays/nz/auk.rem
/usr/share/remind/holidays/nz/can.rem
/usr/share/remind/holidays/nz/cit.rem
/usr/share/remind/holidays/nz/hkb.rem
/usr/share/remind/holidays/nz/mbh.rem
/usr/share/remind/holidays/nz/nsn.rem
/usr/share/remind/holidays/nz/ntl.rem
/usr/share/remind/holidays/nz/ota.rem
/usr/share/remind/holidays/nz/south_canterbury.rem
/usr/share/remind/holidays/nz/stl.rem
/usr/share/remind/holidays/nz/tki.rem
/usr/share/remind/holidays/nz/wgn.rem
/usr/share/remind/holidays/nz/wtc.rem
/usr/share/remind/holidays/pa.rem
/usr/share/remind/holidays/pagan.rem
/usr/share/remind/holidays/pe.rem
/usr/share/remind/holidays/pg.rem
/usr/share/remind/holidays/ph.rem
/usr/share/remind/holidays/pk.rem
/usr/share/remind/holidays/pl.rem
/usr/share/remind/holidays/pr.rem
/usr/share/remind/holidays/pt.rem
%dir /usr/share/remind/holidays/pt
/usr/share/remind/holidays/pt/01.rem
/usr/share/remind/holidays/pt/02.rem
/usr/share/remind/holidays/pt/03.rem
/usr/share/remind/holidays/pt/04.rem
/usr/share/remind/holidays/pt/05.rem
/usr/share/remind/holidays/pt/06.rem
/usr/share/remind/holidays/pt/07.rem
/usr/share/remind/holidays/pt/08.rem
/usr/share/remind/holidays/pt/09.rem
/usr/share/remind/holidays/pt/10.rem
/usr/share/remind/holidays/pt/12.rem
/usr/share/remind/holidays/pt/13.rem
/usr/share/remind/holidays/pt/14.rem
/usr/share/remind/holidays/pt/15.rem
/usr/share/remind/holidays/pt/16.rem
/usr/share/remind/holidays/pt/18.rem
/usr/share/remind/holidays/pt/20.rem
/usr/share/remind/holidays/pt/30.rem
/usr/share/remind/holidays/pw.rem
/usr/share/remind/holidays/py.rem
/usr/share/remind/holidays/ro.rem
/usr/share/remind/holidays/rs.rem
/usr/share/remind/holidays/ru.rem
/usr/share/remind/holidays/sa.rem
/usr/share/remind/holidays/sc.rem
/usr/share/remind/holidays/se.rem
/usr/share/remind/holidays/sg.rem
/usr/share/remind/holidays/si.rem
/usr/share/remind/holidays/sk.rem
/usr/share/remind/holidays/sm.rem
/usr/share/remind/holidays/sv.rem
%dir /usr/share/remind/holidays/sv
/usr/share/remind/holidays/sv/ss.rem
/usr/share/remind/holidays/sz.rem
/usr/share/remind/holidays/td.rem
/usr/share/remind/holidays/th.rem
/usr/share/remind/holidays/tl.rem
/usr/share/remind/holidays/tn.rem
/usr/share/remind/holidays/to.rem
/usr/share/remind/holidays/tr.rem
/usr/share/remind/holidays/tw.rem
/usr/share/remind/holidays/tz.rem
/usr/share/remind/holidays/ua.rem
/usr/share/remind/holidays/uk
/usr/share/remind/holidays/uk.rem
/usr/share/remind/holidays/um.rem
/usr/share/remind/holidays/us.rem
%dir /usr/share/remind/holidays/us
/usr/share/remind/holidays/us/ak.rem
/usr/share/remind/holidays/us/al.rem
/usr/share/remind/holidays/us/ar.rem
/usr/share/remind/holidays/us/as.rem
/usr/share/remind/holidays/us/az.rem
/usr/share/remind/holidays/us/ca.rem
/usr/share/remind/holidays/us/co.rem
/usr/share/remind/holidays/us/ct.rem
/usr/share/remind/holidays/us/dc.rem
/usr/share/remind/holidays/us/de.rem
/usr/share/remind/holidays/us/fl.rem
/usr/share/remind/holidays/us/ga.rem
/usr/share/remind/holidays/us/gu.rem
/usr/share/remind/holidays/us/hi.rem
/usr/share/remind/holidays/us/ia.rem
/usr/share/remind/holidays/us/id.rem
/usr/share/remind/holidays/us/il.rem
/usr/share/remind/holidays/us/in.rem
/usr/share/remind/holidays/us/ks.rem
/usr/share/remind/holidays/us/ky.rem
/usr/share/remind/holidays/us/la.rem
/usr/share/remind/holidays/us/ma.rem
/usr/share/remind/holidays/us/md-extra.rem
/usr/share/remind/holidays/us/md.rem
/usr/share/remind/holidays/us/me.rem
/usr/share/remind/holidays/us/mi.rem
/usr/share/remind/holidays/us/mo.rem
/usr/share/remind/holidays/us/mp.rem
/usr/share/remind/holidays/us/ms.rem
/usr/share/remind/holidays/us/mt.rem
/usr/share/remind/holidays/us/nc.rem
/usr/share/remind/holidays/us/ne.rem
/usr/share/remind/holidays/us/nh.rem
/usr/share/remind/holidays/us/nj.rem
/usr/share/remind/holidays/us/nm.rem
/usr/share/remind/holidays/us/nv.rem
/usr/share/remind/holidays/us/ny.rem
/usr/share/remind/holidays/us/oh.rem
/usr/share/remind/holidays/us/ok.rem
/usr/share/remind/holidays/us/pa.rem
/usr/share/remind/holidays/us/pr.rem
/usr/share/remind/holidays/us/ri.rem
/usr/share/remind/holidays/us/sc.rem
/usr/share/remind/holidays/us/sd.rem
/usr/share/remind/holidays/us/tn.rem
/usr/share/remind/holidays/us/tx.rem
/usr/share/remind/holidays/us/ut.rem
/usr/share/remind/holidays/us/va.rem
/usr/share/remind/holidays/us/vi.rem
/usr/share/remind/holidays/us/vt.rem
/usr/share/remind/holidays/us/wi.rem
/usr/share/remind/holidays/us/wv.rem
/usr/share/remind/holidays/uy.rem
/usr/share/remind/holidays/uz.rem
/usr/share/remind/holidays/va.rem
/usr/share/remind/holidays/ve.rem
/usr/share/remind/holidays/vi.rem
/usr/share/remind/holidays/vn.rem
/usr/share/remind/holidays/vu.rem
/usr/share/remind/holidays/ws.rem
/usr/share/remind/holidays/za.rem
/usr/share/remind/holidays/zm.rem

/usr/share/remind/lang/auto.rem
/usr/share/remind/moonphases.rem
/usr/share/remind/seasons.rem
/usr/share/remind/sun.rem
/usr/share/remind/site/README
/usr/share/applications/tkremind.desktop
/usr/share/pixmaps/tkremind.png
%lang(ca) /usr/share/remind/lang/ca.rem
%lang(da) /usr/share/remind/lang/da.rem
%lang(de) /usr/share/remind/lang/de.rem
%lang(en) /usr/share/remind/lang/en.rem
%lang(es) /usr/share/remind/lang/es.rem
%lang(fi) /usr/share/remind/lang/fi.rem
%lang(fr) /usr/share/remind/lang/fr.rem
%lang(fr) /usr/share/remind/lang/gr.rem
%lang(is) /usr/share/remind/lang/is.rem
%lang(it) /usr/share/remind/lang/it.rem
%lang(nl) /usr/share/remind/lang/nl.rem
%lang(no) /usr/share/remind/lang/no.rem
%lang(pl) /usr/share/remind/lang/pl.rem
%lang(pt) /usr/share/remind/lang/pt.rem
%lang(ro) /usr/share/remind/lang/ro.rem

%changelog
* Mon Feb 10 2025 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 5.3 Patch 2 - 2025-02-09
- CHANGE: remind: Revert a change to the way "-y" tags are generated that
  was introduced in 05.03.01.  The change broke a library that depended
  on it being generated in the old way.
* Sun Feb  9 2025 Detlef Steuer <detlef.steuer@gmx.de>
-  VERSION 5.3 Patch 1 - 2025-02-07
- IMPROVEMENT: TkRemind: When we pop up a timed reminder, make any "Url:"
  info string into a clickable link.
- IMPROVEMENT: rem2pdf: Improve the layout of the small monthly calendars.
- BUG FIX: rem2pdf: Add checks for all Perl dependencies.
* Tue Feb  4 2025 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 5.3 Patch 0 - 2025-02-04
- NEW FEATURE: remind: Add the "INFO" clause to the REM command.  This
  is intended for storing additional metadata about an event, such as
  the location and a longer description.  The intention is to make
  Remind <-> iCal conversions preserve as much information as possible.
- NEW FEATURE: rem2html, rem2pdf, tkremind: Add support for the "Url:"
  info string that turns reminders into hyper-links.  For example,
  consider this reminder:
    REM 15 INFO "Url: https://foo.example" MSG Foo
  The text "Foo" will be made into a link to "https://foo.example"
  by rem2html and rem2pdf.  If you middle-click it in tkremind, it
  will open the URL.
- NEW FEATURE: remind: Add the triginfo() built-in function so a reminder
  body can refer to INFO data.  Add the %%<...> substitution filter as a
  shorthand for [triginfo("...")]
- NEW FEATURE: TkRemind: Add "Location" and "Description" fields when
  creating a reminder; these are converted to INFO clauses.  Also support
  a popup window with the extra information when hovering over a reminder
  in the calendar display.
- IMPROVEMENT: Update the reminder files included with Remind to add
  INFO strings with Wikipedia URLs for various holidays and
  astronomical events.
- IMPROVEMENT: remind: Add the "\xAB" escape sequence for parsing quoted
  strings, where "AB" is a pair of hex digits.
- NEW FUNCTION: remind: Add the escape() built-in function that converts
  problematic characters within a string to the \-escaped versions.
  It's essentially the inverse of how Remind parses a quoted string.
* Thu Jan 23 2025 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 5.2 Patch 3 - 2025-01-22
- NEW FEATURE: remind: Add "TRANSLATE GENERATE" command for generating
  a skeleton set of TRANSLATE commands to make it easier to localize
  Remind.
- NEW FEATURE: remind: Add "q" debug flag for tracing calls to _()
  or %%(...) in the substitution filter; this will help with localizing
  reminder files.
- NEW FILES: remind: Add holidays/lgbtq.rem for LGBTQ holidays.  Add
  country-specific files in holidays/lgbtq/*.rem
- IMPROVEMENT: TkRemind: use "info patchlevel" to display full Tcl/Tk
  version.
- IMPROVEMENT: remind: The DEBUG command issues a warning if given an
  unknown debug flag.
- BUG FIX: remind: "make test" will now succeed even if run between
  23:55 and 00:00 UTC.  This is done with a new --test flag for remind.
- BUG FIX: remind: Avoid potential buffer overflow if someone supplies
  ridiculously-long translations for "am" or "pm".
* Tue Jan  7 2025 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 5.2 Patch 2 - 2025-01-06
- NEW FEATURE: remind: The "-p+" option lets you produce weekly calendars;
  so far, the rem2pdf and rem2html back-ends support rendering of weekly
  calendars.
- NEW FEATURE: remind: The $CalType system variable indicates the type of
  calendar being produced; its value is one of "monthly", "weekly",
  or "none".  "none" signifies agenda mode rather than calendar mode.
- IMPROVEMENT: remind: Warn if a POP-OMIT-CONTEXT matches a
  PUSH-OMIT-CONTEXT that is in a different file.
- CHANGE: remind: Split the "-ds" debug option into two separate options:
  "-ds" for debugging expression-parsing and "-dh" for printing hash
  table statistics on exit.
* Tue Dec 17 2024 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 5.2 Patch 1 - 2024-12-16
- BUG FIX: remind: Fix a logic error that only showed itself on big-endian
  architectures.  Found thanks to Debian testing and a notification from
  Jochen Sprickerhof.
* Mon Dec 16 2024 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 5.2 Patch 0 - 2024-12-16
- MAJOR NEW FEATURE: remind: Add the TRANSLATE command, the _()
  built-in function and the %%(...) substitution sequence.  These allow
  you to localize your reminder files more easily.  The translation table
  is also made available to back-ends like rem2pdf and tkremind,
  which they can use as they see fit.
- MINOR FEATURE: tkremind, rem2html: Localize the names of the moon
  phases.
- MAJOR CHANGE: remind: Remind used to support compile-time localization
  into different languages (French, English, etc.)  That compile-time
  support has been removed and all localization is now done at run-time.
- NEW FEATURE: remind: In JSON daemon mode (-zj), the front-end can
  request translation table entries from the Remind daemon, allowing the
  front-end to localize messages.
- UPDATE: Update national holidays following update to upstream Python
  library.
- MINOR FEATURE: Add standard include/sun.rem file for sunrise/sunset.
- MINOR FEATURE:  The SYSINCLUDE command has been added.  The command:
    SYSINCLUDE foo/bar.rem
  is equivalent to:
    INCLUDE [$SysInclude]/foo/bar.rem
- MINOR IMPROVEMENT: Allow INCLUDE, DO and SYSINCLUDE to include files with
  spaces in their names; in this case, you have to put the filename inside
  double-quotes.
- IMPROVEMENT: remind: Refuse to open subdirectories named "*.rem"
  under a top-level directory rather than trying and failing with a
  confusing error.
- IMPROVEMENT: contrib/remind-conf-mode: Fix a few bugs and choose colors
  that are easier on the eyes.
- IMPROVEMENT: remind: Remind used to have three completely separate
  hash table implementations.  They have all been replaced with a single
  implementation; this new implementation adapts the hash table size based
  on the number of entries and is dramatically faster than the old code
  when there are a large number of entries.
- MINOR FIXES: remind: Fix typos in comments; use memcpy to copy OMIT
  contexts internally.
- BUG FIX: remind: Actually allow the documented 9 levels of INCLUDE
  rather than 8.
- BUG FIX: remind: If an INCLUDE statement failed inside an IF statement,
  Remind would print spurious errors about unmatched IF/ENDIF.  This has
  been fixed.
* Fri Nov 22 2024 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 5.1 Patch 1 - 2024-11-18
- Fix test failure
- VERSION 5.1 Patch 0 - 2024-11-18
- MAJOR IMPROVEMENT: Include holiday files for many countries and
  regions, courtesy of the Python "holidays" project:
  https://pypi.org/project/holidays/  See include/holidays/README
  for usage instructions and important caveats
- NEW FEATURE: remind: Added the $DedupeReminders system variable; see
  its documentation in the remind man page for details.
- NEW FEATURE: remind: Added the FRENAME command to rename a user-defined
  function.  See its documentation in the remind man page for use-cases.
- NEW FEATURE: remind: Added the $DefaultDelta system variable that
  specifies a default (date) delta for reminders that lack one.  It is
  analogous to the default time delta system variable $DefaultTDelta.
- IMPROVEMENT: remind: Added a way for the output of msgsuffix() to appear
  on the same line as a reminder rather than on the next line.  See the
  remind man page for details.
- UPDATE: contrib/ical2rem: Update to upstream version 0.8
- DOCUMENTATION FIXES: Many updates and clarifications to the man pages.
- BUG FIX: Fixed configure.ac so that autoreconf works.
* Thu Oct 17 2024 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 5.0 Patch 7 - 2024-10-16
- NEW FEATURE: tkremind: Add option to create a desktop notification when
  a queued reminder is triggered.  For Tcl/Tk 9.0 or later, uses the native
  "tk sysnotify" facility.  For earlier versions of Tcl/Tk, executes the
  "notify-send" program if possible.
- NEW FEATURE: remind: Add --print-config-cmd option which prints the
  exact ./configure command used to build Remind.  This will let you
  configure future Remind releases exactly the same way an installed
  version was configured.
- UPDATE: include/holidays/ca.rem: Add National Day for Truth and
  Reconciliation to Canadian holiday list.
- MINOR IMPROVEMENTS: Update examples/ansitext and examples/astro
- MINOR IMPROVEMENT: remind: Use HashPJW to hash variable and function
  names; make the hash table size a prime rather than a power of two.
  This seems to improve hash performance ever so slightly in most cases.
- UPDATE: Update contrib/ical2rem to upstream version 0.7.1
- FIX: tkremind: Make tkremind work with Tcl/Tk 8.5 or higher, including
  Tcl/Tk 9.0
- MINOR CHANGE: remind: Add hash table statistics to "-ds" debugging
  output.  This is probably of no use to anyone except the author of
  Remind.
* Mon Sep 16 2024 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 5.0 Patch 6 - 2024-09-16
- NEW FEATURE: remind: Include a file containing the dates of Chinese
  New Year through 2050.
- NEW FEATURE: remind: Add $SuppressImplicitWarnings system variable.
  Setting this to 1 suppresses the warnings "Unrecognized command;
  interpreting as REM" and "Missing REM type; assuming MSG"
- NEW FEATURE: remind: Add --print-tokens command-line argument.  This
  simply prints all of Remind's built-in tokens, functions, and system
  variables.  It's designed to help people who are writing editor
  add-ons for syntax highlighting.
- CHANGE: remind: allow '12:34' to be parsed as a TIME constant.  This
  matches DATEs and DATETIMEs which are enclosed in single-quotes.
  (The quotes are optional for TIME constants, however.)
- IMPROVEMENT: Improve many error messages and warnings.
- UPDATE: contrib/ical2rem: Update to upstream version 0.7
- IMPROVEMENT: contrib/remind-conf-mode: Improve the Emacs
  remind-conf-mode package.  Add new keywords and make comment
  highlighting correct.
- FIX: remind man page: Remove note saying REM can be omitted.
* Mon Sep  9 2024 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 5.0 Patch 5 - 2024-09-02
  * CHANGE: remind: When using the "-c" option and with the SHADE special
  enabled, shade the entire calendar box including the line containing the
  day number.
  * IMPROVEMENT: remind: Better error messages when diagnosing certain
  errors in expressions.
  * IMPROVEMENT: include/holidays/jewish.rem: Remove unnecessary _h()
  function definition.
  * BUG FIX: remind: In a couple of spots when we parsed a character, we did
  not check for an error return.  This has been fixed.
  * BUG FIX: remind: Fix edge-case bugs in "remind -c" output formatting.
  * BUG FIX: make test: Fix a test that was broken for all of September 2024.
  * BUG FIX: remind: Fix a couple of potential file-descriptor leaks.
  * BUG FIX: contrib/ical2rem.pl: Replace "SCHED _sfun" with "+15" to
  hard-code 15-minutes advance warning rather than using an undefined
  scheduling function.  If this is not what you want, you should edit
  ical2rem.pl to suit your taste; it's not officially part of Remind and
  is meant more as a starting point for you to customize than a finished
  product.
  * DOCUMENTATION FIX: Remove obsolete info from Remind man page.
* Mon Sep  9 2024 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 5.0 Patch 4 - 2024-08-29
  * IMPROVEMENT: remind: When checking if a SATISFY expression refers to the
  trigger date, look recursively at any user-defined functions it calls.
  This reduces spurious warnings.
  * CHANGE: remind: Allow any type to be used as the test argument for IIF.
  * IMPROVEMENT: remind man page: Clarify how various types are treated
  in boolean context.
  * VERSION 5.0 Patch 3 - 2024-08-28
  * IMPROVEMENT: remind: Preserve newlines ("%%_" sequences) in calendar
  mode in most cases.  See the remind man page for details.
  * IMPROVEMENT: rem2pdf: rem2pdf can now produce PostScript and
  Encapsulated PostScript output in addition to PDF and SVG.
  * IMPROVEMENT: remind: Emit warnings if a subst_XXX function takes the
  wrong number of arguments, or for custom sequences, if the function
  is not defined.
  * IMPROVEMENT: remind: Emit warnings if WARN/SCHED/OMITFUNC functions
  do not reference their argument.
  * IMPROVEMENT: remind: Allow strings to be used with logical
  operators.  The empty string "" is considered false and all other
  strings are considered true.
  * IMPROVEMENT: remind: Emit warnings for lines that are implicitly
  treated as REM commands; add warnings for REM commands that are
  implicitly treated as MSG-type reminders.
  * IMPROVEMENT: remind: Add an optional fourth argument to the built-in
  ampm() function that specifies not to suppress a leading zero in the
  hour component.
  * IMPROVEMENT: remind: If a SATISFY expression is not constant and
  doesn't reference the trigger date somehow, issue a warning.
  * IMPROVEMENT: remind: Add a warning if a user-defined function is
  redefined.  If you do have a use-case that requires you to redefine
  a function, simply FUNSET it first before FSETting it for the second
  time.
  * DOCUMENTATION FIX: Clarify man pages and remove some information that
  has become incorrect as Remind has evolved.
  * BUG FIX: Fix typos in man pages
* Fri Jul 26 2024 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 5.0 Patch 2 - 2024-07-26
  * IMPROVEMENT: Remind: Revamp how ONCE works.  You can now set a
  special variable $OnceFile to be the path to a timestamp file.  The
  ONCE directive uses this timestamp file to track when it was last
  run rather than the access date of the main reminder script.  This
  is more reliable because it doesn't rely on the atime of a file
  (which might not be maintained accurately) and is not affected if
  you edit your reminder script.
  * CHANGE: Taking input from stdin no longer implies the "-o" option; ONCE can
  work if you set $OnceFile
  * CHANGE: Any of the -c, -n, -p and -s options implicitly enable the
  - o option.  As before, specifying a repeat factor *N or a date that
  is not today on the command-line also implies -o.
  * MINOR NEW FEATURE: Rem2PDF: Add the "--svg" command-line option to produce
  SVG output rather than PDF.
  * MINOR IMPROVEMENT: Remind: Improve the storage efficiency of short
  string constants in compiled expression trees.
  * MINOR IMPROVEMENT: Remind: Remove some obsolete macro definitions
* Mon Jun 10 2024 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 5.0 Patch 1 - 2024-06-08
  * MINOR IMPROVEMENT: Add short-circuit evaluation to the isany() function,
  which now only evaluates those arguments absolutely necessary to determine
  the result.
  * BUG FIX: Mark weekno() as a non-constant function (the zero-argument form
  depends on external conditions.)
  * BUG FIX: Fix a couple of memory leaks.
  * BUG FIX: Don't rely on support for unnamed function parameters; this caused
  compilation failures with older versions of gcc.
* Thu Jun  6 2024 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 5.0 Patch 0 - 2024-06-06
  * MAJOR CHANGE: The expression evaluation engine has been completely replaced
  with a new one that splits parsing and evaluating into two separate steps.
  It also features short-circuit evaluation of &&, ||, iif() and choose().
  This should speed up expression-heavy reminder files.
  NOTE INCOMPATIBILITY: In expressions with side-effects, the short-circuit
  evaluation might change the result you get.  For example, consider
  running the following file through: remind file.rem 2024-06-04
    SET a trig("Mon +7") || trig("Thu +7")
    MSG trig = [trig()]
  Older Remind versions will output:
    trig = 2024-06-06
  whereas this version outputs:
    trig = 2024-06-10
  because the second part of the "||" expression is not evaluated.  The vast
  majority of Remind expressions do not have side-effects and should yield
  the same results as before.
  The newer expression engine also permits recursive functions, but
  these are not recommended.  Still, if you want to, you can do:
    fset factorial(n) iif(n <= 1, 1, n*factorial(n-1))
  and it will work for values of n that don't cause integer overflow.
  * IMPROVEMENT: If there's an unmatched PUSH-OMIT-CONTEXT, print the
  filename and line number containing it.
  * IMPROVEMENT: If there's an IF with a missing ENDIF, print the filename
  and line number of the IF statement.
  * NEW FEATURE: Add EXPR OFF command to completely disable expression
  evaluation.  Useful if you INCLUDE files that you don't expect to
  contain expressions and may come from slightly untrustworthy sources.
  * NEW FEATURE: Add $ExpressionTimeLimit system variable to enforce a
  maximum limit on how long evaluating an expression is allowed to take.
  * NEW FEATURE: Add --max-execution-time=n command-line option to terminate
  Remind if it runs for more than n seconds.
  * CHANGE: Make the command-line option "-ifoo" equivalent to "-ifoo=0"
  * CHANGE: Permit a literal [ in a reminder by using the sequence [[
  The old ["["] still works.
  * BUG FIX: In "purge" mode, Remind would sometimes purge reminders with
  a relative "SCANFROM" which haven't actually expired.  This has been fixed.
  * BUG FIX: Disallow something like: FSET func(x, x) expr
  which shouldn't have been allowed in the first place.
  * BUG FIX: Replace leading spaces with tabs in Makefiles (per Emanuele Torre
  and Tim Chase)
* Tue Apr 30 2024 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 4.3 Patch 7 - 2024-04-29
  * IMPROVEMENT: build.tk: Add a note if build.tk obtains default settings
  from an existing Remind installation.
  * IMPROVEMENT: configure: Pass all args to AC_INIT including the Remind
  home page.  Remove some unused autoconf cruft.
  * IMPROVEMENT: Use standard C library versions of strdup, strcasemp and
  strncasecmp where available, rather than using our own versions.
  * MINOR FEATURE: remind: Make $Tt a synonym for trigtime().
  * BUG FIX: remind: Make sure shellescape() doesn't mangle UTF-8 characters
  with high-bits set.
  * BUG FIX: remind: Don't rely on undefined behavior of "%%" operator in
  the ord() built-in function.
  * BUG FIX: remind: Do not clear out trigtime() unnecessarily.  Before,
  you could not write things like the following; now you can:
    REM Tue AT 11:30 DURATION 0:30 MSG Thing 1
    REM Tue AT [trigtime()+trigduration()] DURATION 1:00 MSG Thing 2
    REM Tue AT [trigtime()+trigduration()] DURATION 0:45 MSG Thing 3
  for successive reminders that should be moved as a block if the time of
  the first one changes.
  * BUG FIX: Don't update trigdate() or trigtime() while parsing a REM
  statement... only when actually computing the trigger.
* Wed Apr 10 2024 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 4.3 Patch 6 - 2024-04-02
  * NEW FILE: Add [$SysInclude]/holidays/pt.rem - Portuguese holidays, courtesy
  of Joop Kiefte.
  * BUG FIX: remind: Fix compile error on systems that don't support inotify(7).
  * BUG FIX: remind: Fix test failures on FreeBSD.  On FreeBSD, you have to copy
  the result of getenv() or else a subsequent setenv() can change the stored
  value.
  * VERSION 4.3 Patch 5 - 2024-04-01
  * IMPROVEMENT: remind: Use inotify to detect reminder file changes
  even in regular daemon mode (-zn where n>0).
  * INTERNAL IMPROVEMENTS: Rearrange and refactor some code.
  * FIXES: Various fixes and improvements to man pages.
  * BUG FIX: remind: Handle queued "SPECIAL COLOR" reminders correctly.
  * BUG FIX: remind: Preserve the value of $DefaultColor that was in effect
  when a reminder was queued; restore it before issuing the queued reminder.
  * VERSION 4.3 Patch 4 - 2024-03-25
  * NEW FEATURE: remind: Add the new "multitrig" function, which is how "trig"
  should have worked in the first place.  See man page for details.
  * IMPROVEMENT: tkremind: Make errors in your reminders file stand out more
  prominently.
  * IMPROVEMENT: tkremind: If you click on an error in the "Errors..." popup,
  tkremind will open a text editor on the offending file and line.
  * IMPROVEMENT: tkremind: Format the "Queue..." output better and make queue
  items clickable; clicking on a queue item opens a text editor on the
  corresponding file and line.
  * IMPROVEMENT: Add a standard [$SysInclude]/moonphases.rem file to display
  moon phases on your calendar.
  * IMPROVEMENT: Clean up the demo code in www/ and add PDF output.
  * BUG FIX: tkremind: Correctly handle filenames containing spaces and other
  characters that tend to confuse the shell.
  * BUG FIX: tkremind: Raise dialog boxes after errors so that they
  remain visible.
  * CLEANUP: tkremind: Remove some dead code.
  * VERSION 4.3 Patch 3 - 2024-03-18
  * IMPROVEMENT: tkremind: Update icon to include a white border so it shows
  up better on dark backgrounds.
  * IMPROVEMENT: C code: Fix a number of cppcheck static-analysis warnings.
  * IMPROVEMENT: remind: Update the "-zj" protocol to include a queue-id for
  each queued reminder and add the DEL client command to delete a specific
  item from the queue.  Used by tkremind to implement "don't remind me about
  this again today."
  * MINOR NEW FEATURE: Add a "-ds" debugging flag to print out expression-parsing
  stack high-water marks on exit.  This esoteric feature is of no use to
  anyone but the Remind author.
  * IMPROVEMENT: tkremind: Stop using the deprecated tk_dialog command in favor
  of the newer tk_messageBox command.
  * IMPROVEMENT: remind: In server mode, try to minimize redraws by
  consuming inotify events until at least 0.2s elapses without an
  event appearing.
  * BUG FIX: tkremind:  The "Don't remind me about this again today" feature
  was unreliable and only worked for reminders created with TkRemind itself.
  It has been made more reliable and works with any reminder.
  * BUG FIX: remind: Make it a syntax error if a local OMIT in a REM statement
  is not followed by at least one weekday name.
* Wed Mar  6 2024 Detlef Steuer <detlef.steuer@gmx.de>
-
  VERSION 4.3 Patch 2 - 2024-03-01
- BUG FIX: remind: Fix a logic error when implementing the RUN command in
  server mode.  As it turns out, the error is harmless, but it's best to do
  things correctly.
- BUG FIX: The Makefile would install the tkremind.png and tkremind.desktop
  files in the wrong location.  This has been fixed.
  * VERSION 4.3 Patch 1 - 2024-02-29
- BUG FIX: tests:  "make test" could fail because of a bad test.  This
  has been fixed.  There are no actual code changes to any of the programs
  in Remind compared to 04.03.00.
  * VERSION 4.3 Patch 0 - 2024-02-29
- IMPROVEMENT: remind: If Remind is compiled on a system that supports
  inotify, then in server mode (-z0 or -zj) it monitors the reminders file
  and restarts itself if it detects a change, and also notifies the client.
  Moving inotify support directly into Remind means that tkremind no longer
  has to invoke a separate inotifywait process.
- IMPROVEMENT: remind: Set the CLOEXEC flag on files we open so we
  don't leak file descriptors to programs that we run.  While I don't
  think there's a security issue here (any program you run can do
  anything as your userid anyway) it's best to be clean and tidy.
- IMPROVEMENT: remind: Add localization for the Catalan language, courtesy
  of Eloi Torrents.
- IMPROVEMENT: tkremind: Add a .desktop file and icon so TkRemind can be
  integrated into the desktop menu system, courtesy of Eloi Torrents.
- CHANGE: Add a new server mode with the "-zj" flag.  This is just
  like "-z0" except it uses JSON messages to communicate with the
  client rather than an ad-hoc protocol.  The "-z0" mode is still
  supported, but is deprecated.
- CHANGE: In server mode (-z0 or -zj) any RUN-type reminders, or message
  commands of the "-kcommand" type are run with standard input and standard
  output connected to /dev/null.  NOTE INCOMPATIBILITY: If you previously
  relied on RUN-type reminders to pop up reminders in TkRemind, they no
  longer do.  If you want this, you'll have to get the command that you
  run to pop up its own window with "xmessage" or something similar.
- IMPROVEMENT: tkremind: Make the "Go to date..." dialog non-modal.
- CHANGE: remind: Allow the argument to easterdate() and
  orthodoxeaster() to be omitted, in which case it defaults to
  today().
- BUG FIX: Miscellaneous man page fixes.
- BUG FIX: Fix a leap-year edge-case.  The reminder: REM 29 MSG whatever
  was not triggered on Feb 29 of leap years.
- BUG FIX: rem2html: Make the version of rem2html track the version of
  Remind.  Noted by Ian! D. Allen.
* Tue Feb  6 2024 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 4.2 Patch 9 - 2024-02-04
- CHANGE: remind: Do not attempt to guess terminal background color on
  startup.  Only obtain it as needed.  This can prevent mojibake from
  appearing on terminals that don't support the color query escape
  sequence.
- IMPROVEMENT: remind: Add new system variables $NumFullOmits,
  $MaxFullOmits, $NumPartialOmits and $MaxPartialOmits.
- IMPROVEMENT: remind: Issue a warning if someone OMITs every possible date.
- IMPROVEMENT: remind: In several error messages complaining about limits
  being exceeded, include the actual limit in the error message.  Clarify
  the man page regarding limits on the number of OMITs.
- MINOR NEW FEATURE: remind:  The expression STRING * INT or INT * STRING
  is now accepted and yields a string that is INT concatenations of the
  origina STRING.  In this case, INT must be non-negative and the total
  string length can't exceed $MaxStringLen.
- DOCUMENTATION: Add "Astronomical Algorithms" by Jean Meeus to bibliography.
- DOCUMENTATION FIX: Update address of the Free Software Foundation in the
  license file.
- DOCUMENTATION: Note that rem2ps is deprecated and will not received any
  new features.  Further development will happen on rem2pdf.
- BUG FIX: Preserve the filename() and priority context for queued reminders.
  Previously, the filename information was lost and the priority was
  coming from uninitialized memory (yikes!).  bug found by Alexander
  Möller.
- BUG FIX: build.tk: Various minor improvements.
- BUG FIX: remind: In server mode, if we de-queue a reminder without
  triggering it, issue a "NOTE queued %%d" message to update the
  client's notion of the queue size.
- BUG FIX: tkremind: Fix typo found by Lorenzo Bazzanini.
* Fri Dec 15 2023 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 4.2 Patch 8 - 2023-12-14
- NEW FEATURE: Add the $MaxLateMinutes system variable.  This suppresses
  a queued time reminder if the current time is more than $MaxLateMinutes
  past the trigger time.  (This typically only occurs if the computer
  has been suspended/hibernated and then resumed.)
- IMPROVEMENT: tkremind: If an error occurs during printing, catch it
  and change the Queue... button to Errors... (the same way errors in
  reminder files are handled.)
- IMPROVEMENT: rem2html: add the --utf8 flag to set the HTML charset to
  UTF-8.
- MINOR IMPROVEMENTS: Refactor some of the C code; use symbolic exit
  statuses and file descriptors for stdin/stdout/stderr where possible.
- BUG FIX: configure.in: Use better option detection so we don't use the
  unsupported option -ffat-lto-objects if compiling with clang instead of gcc.
- BUG FIXES: Many fixes to man pages, some by Jochen Sprickerhof
- MINOR BUG FIX: If Remind puts itself in the background, only close
  stdout/stderr if they are not associated with a terminal.  If
  we close a descriptor, dup /dev/null onto it.
- MINOR BUG FIX: Catch SIGCONT when running in daemon/background mode.
  This forces the select() call to be interrupted so we can update the
  sleep time.  This really only matters if the computer or the background
  Remind process is suspended and then resumed.
* Mon Oct  9 2023 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 4.2 Patch 7 - 2023-10-09
- IMPROVEMENT: remind: On 32-bit systems, attempt to use a 64-bit time_t
  if the C library supports that.  This lets Remind work properly with
  dates after 2038 in the few cases it has to call mktime() internally.
- MINOR NEW FEATURE: remind: Attempt to obtain the terminal background
  color using an OSC sequence.  This normally only happens if standard
  output is a terminal, but can be forced with the '-@..,t' option.
- MINOR NEW FEATURE: remind: Add "--version" long option to print out
  Remind's version and exit.
- MINOR IMPROVEMENT: tkremind: Use a higher-resolution PNG image for
  the icon.
- MINOR IMPROVEMENT: remind-conf-mode.el: Update highlighting rules
  courtesy of Bill Benedetto
- MINOR CHANGE: Make AT optional.  If we encounter a TIME in a REM
  command, implicitly begin an AT clause.
- DOCUMENTATION: Many minor fixes and improvements courtesy of Dan Jacobson.
- BUG FIX: Make "-w0" set the calendar width based on standard output
  rather than setting it to zero and causing an infinite loop.
* Tue Sep 12 2023 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 4.2 Patch 6 - 2023-09-12
- NEW FEATURE: remind: The "nonomitted()" function takes an optional
  extra INT argument called "step".  See man page for details.  Also
  allows the "start" argument to be greater than the "end" argument,
  in which case they are effectively swapped.
- NEW FEATURE: remind: The "slide()" function takes an optional extra
  INT argument called "step", similar to "nonomitted()".  See man page
  for details.
- NEW FEATURE: remind: Added the $ParseUntriggered system variable;
  see the man page for details.  You almost certainly will never need
  to use this.
- NEW FILE: holidays/ie.rem: Added Irish holidays, courtesy of
  Amy de Buitléir.
- CHANGE: remind: The "-tn" option sets all REM statement deltas to
  ++n rather than adding n to any existing REM statement's delta.
  Additionally, the corresponding system variable $DeltaOffset has
  been renamed to $DeltaOverride.
- NEW OPTION: remind: Add the "-tz" option to explicitly set all
  REM statement deltas to zero.
- DOCUMENTATION FIX: remind: various documentation improvements.
- BUG FIX: Correct some errors in Italian localization, courtesy of
  Emanuele Torre
* Tue Apr 11 2023 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 4.2 Patch 5 - 2023-04-11
- MINOR IMPROVEMENT: remind: If someone uses OMIT yyyy-mm-dd UNTIL yyyy-mm-dd
  give a better error message suggesting THROUGH instead of UNTIL.
- BUG FIX: remind: The fix for the combination of ADDOMIT and SATISFY that
  appeared in version 04.02.00 was not complete; the bug has finally been
  properly fixed.
- BUG FIX: remind: Remove an unnecessary #include <sys/file.h>.
  Nothing needed that and it broke compilation on FreeBSD.
- VERSION 4.2 Patch 4 - 2023-03-15
- NEW FEATURE: Remind: Add "htmlescape" and "htmlstriptags" built-in
  functions.
- NEW FEATURE: Rem2PDF: Add the "--wrap, -y" option to ensure that no
  printed calendar takes up more than 5 rows.  If a calendar would normally
  require 6 rows, wrap it so the last day or two appear on the first
  row instead of on a sixth row.
- NEW FEATURE: Remind: Improve the -k option to allow specification of
  separate commands for immediately-issued vs. queued reminders.  For
  example:
    remind '-kcmd1 %%s' '-k:cmd2 %%s' ...
  will use "cmd1" for immediately-issued reminders and "cmd2" for queued
  ones.  If you only use '-k:cmd2 %%s' then immediately-issued reminders
  are simply printed as usual rather than being passed to a command.
- IMPROVEMENT: Remind:  Make "SPECIAL MSG" the same as just "MSG" and
  the same for MSF, RUN, PS and PSFILE.  This effectively lets you use
  expression-pasting to determine the type of a REM command; see the
  remind(1) man page for details.
- MINOR IMPROVEMENT: If "make test" fails, output up to 200 lines of diff
  so we can see immediately what failed.
- DOCUMENTATION FIX: Fix some typos; fix TkRemind syntax description.
- TEST FIX: Make tests run reliably regardless of local machine's time zone.
- BUG FIX: TkRemind: Don't crash if local installation of Tk lacks the
  - underlinefg configuration option.
- BUG FIX: examples/defs.rem: Fix up US Thanksgiving example.
- BUG FIX: include/holidays/us.rem: Add logic for US holidays that are
  observed on a Friday if the holiday is a Saturday, or on a Monday if the
  holiday is a Sunday.
- BUG FIX: TkRemind: Don't cut off MOON text at the first white-space
  character.
- BUG FIX: Remind: prevent functions defined on the command-line (as in
  remind '-if(x)=whatever') from segfaulting.
* Fri Feb 10 2023 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 4.2 Patch 3 - 2023-02-10
- NEW FEATURE: Remind: add the orthodoxeaster() function to return the
  date of Orthodox Easter.
- IMPROVEMENT: Add Greek language support courtesy of JeiEl.
- IMPROVEMENT: Add Greek holiday file courtesy of JeiEl.
- IMPROVEMENT: Fix the Perl code (rem2pdf, rem2html) to silence Perl::Critic
  warnings
- IMPROVEMENT: Many internal code tweaks to eliminate many cppcheck
  static analysis warnings.
- DOCUMENTATION IMPROVEMENT: Clarify the distinction between a "time"
  and a "duration" as suggested by Ian! D. Allen.
- BUG FIX: Remind: Fix incorrect interaction between sortbanner() and
  MSF-type reminders.  Bug found by Tim Chase.
- BUG FIX: examples/defs.rem: Fix the calculation of US Tax Day as per
  Tavis Ormandy and Tim Chase.  Also fixed in include/holidays/us.rem
- BUG FIX: Remind: Add missing #include <fcntl.h> to funcs.c
- BUG FIX: Remind: Fix undefined integer-overflow behavior in built-in abs()
  function.  Pointed out on IRC by "ubitux".
* Mon Jan  2 2023 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 4.2 Patch 2 - 2023-01-01
- NEW FEATURE: Remind: Add the NOQUEUE modifier to the REM statement for
  explicitly telling Remind not to queue a timed reminder.
- NEW FEATURE: Remind: Add soleq() function to return the DATETIME of
  solstices and equinoxes.  See $SysInclude/seasons.rem for an example
  of how to use the function.
- MINOR IMPROVEMENT: Update examples/astro to include solstices and equinoxes.
- BUG FIX: TkRemind: Provide better error indication if showing today's
  reminders fails on startup.
- BUG FIX: Remind: Refuse to read world-writable directories.
- BUG FIX: Tests depended on the actual date of the test run.  This has
  been fixed.
- INTERNAL CHANGE: Remind: Change inappropriately-named "Julian" variables
  to "DSE" (= Days Since Epoch) since they weren't really holding true
  Julian dates.
- INTERNAL CHANGE: Add "SPDX-License-Identifier" tags to most files.
* Fri Dec 16 2022 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 4.2 Patch 1 - 2022-12-15
- MINOR IMPROVEMENT: TkRemind: If "Extra Remind Options" contains -m, make
  TkRemind start the calendar with Monday instead of Sunday.
- MINOR IMPROVEMENT: Sample files: Add French holidays courtesy of
  Clément Bœsch.
- MINOR IMPROVEMENT: A few performance fixes, likely not even noticeable in
  most cases.
- MINOR FIXES: Fix misleading comments in the source code.
- MINOR FIX: Remove a bunch of dead code in the moon-phase routines.
- MINOR FIX: Remove unnecessary %%"...%%" markers in holidays/us.rem
- MINOR FIX: Don't use the -ffat-lto-objects if we're compiling with Clang.
- MINOR FIX: Remind: Fix a broken printf-format string (need to double up on %%
  to get a literal %% in the output.)
- BUG FIX: Make test suite pass regardless of the date on which it is run.
  D'oh!!!
- BUG FIX: Make sure the banner gets printed each time through a "*N"
  command-line option loop.
* Fri Oct 14 2022 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 4.2 Patch 0 - 2022-10-14
- NEW FEATURE: remind: Allow weekdays to be globally-omitted.  For example:
    OMIT Saturday Sunday
  globally-omits all Saturdays and Sundays.
- NEW FEATURE: remind: Add ansicolor() built-in function to make it easier
  to colorize reminders on the terminal.  Suggested by Tim Chase.
- NEW FEATURE: remind: Add several special variables related to the color
  mode: $UseVTColors, $UseBGVTColors, $Use256Colors, $UseTrueColors and
  $TerminalBackground.  Based on a suggestion by Tim Chase.
- NEW FEATURE: remind: Add utctolocal() and localtoutc() built-in functions.
- NEW FEATURE: remind: Add timezone() built-in function.
- NEW FEATURE: remind: Add trigtags() function per suggestion from Tim Chase.
- NEW FEATURE: remind: The $AddBlankLines system variable controls whether or
  not a blank line is added after each reminder.
- NEW FEATURE: remind: The built-in functions columns() and rows() return the
  width and height of the terminal (in character positions) respectively.
- NEW FEATURE: remind: The built-in function columns("string") returns the
  number of columns occupied by "string" on the terminal, taking into account
  double-width Unicode characters and zero-width ANSI escape sequences.
- NEW FEATURE: remind: You can add custom substitution sequences of the form
  %%{name} or %%*{name} that end up calling the function subst_name and using
  its return value as the replacement for the substitution sequence.
- NEW FEATURE: remind: Add the FUNSET command to undefine a user-defined
  function.
- NEW FILES: Add standard include files holidays/jewish.rem and
  ansitext.rem (the latter defines standard ANSI escape codes for
  changing text attributes such as bold, underline, etc.)
- NEW EXAMPLES: add examples/alignmemt.rem, examples/ansitext and
  examples/astro
- BUG FIX: remind: Make MSF correctly format UTF-8 text and text with
  embedded ANSI color-changing codes.
- BUG FIX: remind: Make ADDOMIT actually work correctly in a SATISFY-type
  REM command.  Bug found by Gunther Reißig
- BUG FIX: Convert documentation files and src/lang.h to UTF-8.  Patch
  from Jochen Sprickerhof.
- BUG FIX: Fix tests in non-UTF-8 locales.
- BUG FIX: Fix a few problems with the include/holidays/us.rem file.
- BUG FIX: remind: Fix an ancient logic error in DBufPutc that hurt
  performance.
- MINOR IMPROVEMENT: Clean up code and remove some dead code.
* Wed Sep 28 2022 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 4.1 Patch 0 - 2022-09-25
- NEW FEATURE: remind: "remind -c" now supports the MOON special, printing
  the moon phases in the calendar if the locale supports UTF-8 encoding.
- NEW FEATURE: remind: "remind -c" now supports the SHADE special.  Works
  best with the 256-color extended XTerm palette or 24-bit true-color
  terminal escape sequences.
- NEW FEATURE: remind: "remind -c" now supports the WEEK special.
- NEW FEATURE: remind: The new "stdout()" function returns a string describing
  where stdout is going.  Examples of return values are "TTY" if remind's
  output is going to terminal, "FILE" if it's redirected to a plain file,
  or "PIPE" if it's going to a pipe.  See the man page for all the details.
- NEW FEATURE: Add the "-wt" option to set the calendar width to the terminal
  width even if standard output is a pipe.  Useful for situations like this:
    remind -wt -c .reminders | less -R
- CHANGE: "make install" now no longer strips debugging symbols from the
  remind and rem2ps executables.  Use "make install-stripped" if you want
  them stripped.
- CHANGE: remind: "remind -c" highlights today's date in bold, if
  colors are enabled.
- CHANGE: Dump string values with control characters escaped.
- DOCUMENTATION FIX: Document behavior of DO and filedir() with respect
  to symbolic links.
- DOCUMENTATION FIX: Add home page link to man pages.  Suggested by Ian! D.
  Allen.
- DOCUMENTATION FIX: Make date in man pages actually be the release date.
  Include Remind version in man pages.  Also suggested by Ian! D. Allen.
- DOCUMENTATION FIX: Fix inaccuracy in how string constants were documented.
- BUG FIX: Makefiles: Pass CFLAGS at link-time so link-time optimization
  actually happens.  Pointed out by Zolan Puskas.
- BUG FIX: If the first REM command to trigger was a RUN command, the banner
  would not print.  This has been fixed.
- BUG FIX: replace deprecated 'fgrep' with 'grep -F' (Jochen Sprickerhof)
- BUG FIX: make "make test" depend on "make all" (Jochen Sprickerhof)
- BUG FIX: make "REM ... SATISFY ... MSG foo" respect $DefaultColor.  Bug
  reported by Gunther Reißig.
- BUG FIX: Don't consider IFTRIG true if we could not compute a trigger date.
  Bug noted by Gunther Reißig
* Fri Aug 19 2022 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 4.0 Patch 3 - 2022-08-16
- IMPROVEMENT: remind: add plain_body and calendar_body JSON keys in -pp...
  output.
- BUG FIX: tkremind: Don't create empty files called '&1' when creating
  a new reminder.
- BUG FIX: remind: Don't call signal-unsafe functions from signal handler
* Tue Aug  2 2022 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 4.0 Patch 2 - 2022-08-02
- IMPROVEMENT: remind: Allow more forms of OMIT as per Ian D. Allen!'s request:
    OMIT Month [THROUGH Month]
    OMIT Day Month [THROUGH Day Month]
    OMIT Day Month Year [THROUGH Day Month Year]
- BUG FIX: Make $T behave as documented, exactly like trigdate().  $T would
  return '1989-12-31' rather than 0 if the trigger date was not valid.
- BUG FIX: TkRemind: Fix resizing bug for a calendar with 6 rows.
- DOCUMENTATION IMPROVEMENT: Improve TkRemind documentation; document use
  of inotifywait if available.
* Sat Jun  4 2022 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 4.0 Patch 1 - 2022-06-03
- IMPROVEMENT: Add $SuppressLRM system variable to suppress the UTF-8
  Left-to-Right mark in "remind -c" output.
- DOCUMENTATION FIX: Document the "q" sub-option to the "-p" option.
* Tue Apr  5 2022 Detlef Steuer <detlef.steuer@gmx.de>
-  VERSION 4.0 Patch 0 - 2022-04-04
- MAJOR NEW FEATURE: remind: Remind output can effectively be
  translated into other languages at run-time.  A number of system
  variables let you translate English words to another language, and a
  mechanism for altering the substitution filter at run-time lets you
  translate its output so the results are idiomatic.  See the man page
  sections "RUN-TIME SUPPORT FOR OTHER LANGUAGES", "RUN-TIME
  MODIFICATION OF THE SUBSTITUTION FILTER" and "LANGUAGE PACKS".
- NEW FEATURE: remind: Add the pad() built-in function
- NEW FEATURE: tkremind: Day numbers can be displayed left-aligned,
  centered or right-aligned.
- IMPROVEMENT: contrib/remind-conf-mode: The Emacs syntax-highlighter
  has been updated with the latest system variables and functions
  and has been made case-insensitive.
- IMPROVEMENT: remind, rem2ps: Use link-time optimization with gcc if
  possible.
- IMPROVEMENT: remind: Print better diagnostics when errors occur inside
  a user-defined function.  We now show the stack trace to make it easier
  to figure out where the error actually is.
- CHANGE: Add a "q" sub-option to the "-p", "-pp", and "-ppp" options.
  This causes Remind *not* to remove the %%"...%%" marker sequence from
  remind bodies.
- BUG FIX: rem2pdf: Make rem2pdf respect the --prefix ./configure flag.
  Loosely based on patch by Jonathan Kamens.
- BUG FIX: tkremind: Fix the "-m" flag, which was broken in 03.04.00.
- BUG FIX: Fix the overflow-detection functions so they work with link-time
  optimization.  The previous versions would be optimized away.
- BUG FIX: Warn if the arguments to the "-@" option are out of range.
  Problem noted by Ian! D. Allen.
- BUG FIX: Always interpret $Latitude and $Longitude input values in the
  "C" locale.  (We do accept localized input, but warn.)
- BUG FIX: Fix many spelling mistakes caught by Jens Schleusener
* Sat Mar 26 2022 Detlef Steuer <detlef.steuer@gmx.de>
- remind-nostrip.patch removed, no longer needed
* Sun Mar 20 2022 Detlef Steuer <detlef.steuer@gmx.de>
- nostrip-patch removed, does no longer apply, and no longer needed
- Version 3.4 Patch 2 - 2022-03-14
- NEW FEATURE: remind: Add syntactic sugar to simplify some common
  types of reminders.  See "SYNTACTIC SUGAR FOR REM" in the remind
  man page.  Based on suggestions from Ian! D. Allen.
- CHANGE: examples/defs.rem: The examples file has been updated to use
  the newer syntactic sugar.
- CHANGE: remind: Always parse the body of REM statements to catch
  expression errors.  In the past, something like:
    REM 2025-01-02 MSG [1/0]
  would not cause a division-by-zero error except on 2025-01-02.  Now,
  the error is always caught.  NOTE POTENTIAL INCOMPATIBILITY: There may
  be edge-cases when formerly-valid remind scripts now trigger errors.
  However, this is pretty unlikely.
- NEW FEATURE: remind: Add the "trig" function to allow more
  expressiveness when creating triggers.  See man page for details.
- IMPROVEMENT: tkremind: Tweak the calendar display; improve ability to
  customize colors, including supplying two built-in themes.  Based on
  patch and suggestion from Paulo (last name unknown).
- IMPROVEMENT: tkremind: TkRemind handles errors in reminders scripts
  much more unobtrusively.  Instead of popping up a modal dialog box
  with almost-unreadable error output, it discreetly notifies you of
  errors with a button that lets you view the specific error messages
  in a more readable format.
- IMPROVEMENT: examples/remind.vim: Update list of keywords in vim syntax
  highlighting file.
- IMPROVEMENT: contrib/remind-conf-mode: Update the list of keywords,
  functions and variables in the Emacs syntax-highlighting file.  Also make
  it match them case-insensitively.
- CHANGE: remind: Increase $MaxSatIter default to 1000 instead of 150.
  Computers are much faster than when I first wrote remind and they
  can handle this higher limit easily.  The higher limit also enables
  certain reasonable reminders that failed in the past because of the
  low SATISFY iteration limit.
- CHANGE: remind: The "||" operator now returns the value of the first
  non-zero operand rather than just returning 1 or 0.  Similarly, "&&"
  returns 0 if either operand is false or the value of the last
  operand if both operands are true.
    NOTE POTENTIAL INCOMPATIBILITY: Remind scripts that depend on ||
    and && always returning exactly one of 1 or 0 may need
    adjustment.
- CHANGE: The || and && operators can accept any non-STRING type as long
  as both operands have the same type.  The "false" values are defined
  as follows; true values are any other value:
    INT:      0
    TIME:     00:00
    DATE:     '1990-01-01'             (the Remind epoch)
    DATETIME: '1990-01-01@00:00'       (the Remind epoch)
- IMPROVEMENT: remind: Issue diagnostics if an UNTIL or THROUGH date
  is earlier than any possible trigger date, as well as an UNTIL date
  with a fully-specified date and no repeat ("*N").  Suggestion from
  Ian! D. Allen.
- BUG FIX: tkremind: If the same moon phase appeared twice in a month,
  TkRemind would not display the first occurrence correctly.  This has
  been fixed.
- BUG FIX: rem2pdf: Fix typos in the man page.
- BUG FIX: remind: The IF command documentation didn't reflect how it
  actually worked; now it does.
- BUG FIX: remind: Use correct UNTIL/THROUGH keyword in error message.
- BUG FIX: rem2pdf: Correct the calculation that warns about an over-full
  calendar box.  Problem noted by Jonathan Kamens.
- BUG FIX: remind: The "remind -c" output would sometimes be incorrect if
  scripts with double-wide characters were used.  This has been fixed.
- BUG FIX: remind: The "remind -c" output would sometimes be incorrect
  if right-to-left scripts were used in reminders.  This has been fixed.
* Wed Feb 23 2022 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 3.4 Patch 1 - 2022-02-23
- MINOR IMPROVEMENT: Support the INSTALL_BASE environment variable for
  installing rem2pdf in a non-standard location like your home directory.
  This is passed in to rem2pdf's Makefile at build and install time.
- MINOR IMPROVEMENT: ./configure: Add --disable-perl-build-artifacts flag
  to avoid installation of perllocal.pod and .packlist files.
- BUG FIX: tkremind: If the system date rolls over, update the display
  to correctly highlight the current date.  This worked in older versions
  of Remind, but was broken by 03.04.00.
- BUG FIX: rem2pdf: The small calendar font would sometimes be scaled
  incorrectly so the small calendar overflowed the box.  This has been
  fixed.
* Sun Feb 13 2022 Detlef Steuer <detlef.steuer@gmx.de>
- VERSION 3.4 Patch 0 - 2022-02-10
- MAJOR CHANGE: Remind and its helpers (except for rem2ps) fully support
  UTF-8.  If your system locale is a UTF-8 locale and your terminal
  can handle UTF-8 encoding, you can enjoy full Unicode support in Remind.
- NEW FEATURE: Added a rem2pdf Remind-to-PDF converter.  It can handle
  the full UTF-8 character set and features a new PANGO special reminder
  type that lets you format the text in the PDF calendar (by changing the
  font size, color, underlining, etc.)
- NEW FEATURE: remind:  New system variables $Sunday through $Saturday
  and $January through $December let you set weekday and month names
  to whatever you like, permitting you to produce calendars in your
  local language, even if it's not one of the languages Remind supports
  by default.
- NEW FEATURE: tkremind: If rem2pdf installed, TkRemind offers you the
  choice of PDF or PostScript output in the Print dialog.
- CHANGE: remind: Increase the number of allowed "full OMITs" from 500
  to 1000.
- CHANGE: Remove the annoying code that slowed compilation and running
  on Windows and Mac OS X.  I believe the point has been made and free
  OSes have enough of a critical mass that the annoyances are
  counter-productive.
- CLEANUP: remind: C source code: Replace the LAT_DEG, LAT_MIN,
  LAT_SEC and LON_DEG, LON_MIN, LON_SEC macros with DEFAULT_LATITUDE
  and DEFAULT_LONGITUDE.
- CLEANUP: remind: C source code: Remove various unused or obsolete macros.
- BUG FIXES: Minor fixups to groff source and Makefiles courtesy of
  Jochen Sprickerhof.
- BUG FIX: Properly support formatting of double-wide characters in the
  terminal mode "remind -c" calendar.
- BUG FIX: rem2html: Document how to highlight today with a red border
- BUG FIX: rem2html: Generate and install a man page for rem2html
- BUG FIX: remind: Get rid of LAT_DEG/LAT_MIN/LAT_SEC and
  LON_DEG/LON_MIN/LON_SEC macros in favour of DEFAULT_LATITUDE and
  DEFAULT_LONGITUDE.
- IMPROVEMENT: All localized languages now use UTF-8 exclusively.
  Support for old character encodings like ISO-8859-1 and ISO-8859-2
  has been dropped since modern UNIXes have pretty much standardized
  on UTF-8.
- CHANGE: remind: Non-English versions of remind *no longer* accept
  non-English month- and weekday-names in trigger specifications.  This
  was a misfeature.  NOTE INCOMPATIBILITY.
* Tue Jan 25 2022 Detlef Steuer <detlef.steuer@gmx.de>
  * VERSION 3.3 Patch 12 - 2022-01-24
- UPDATE: rem2html: Use JSON::MaybeXS instead of JSON::Any, since JSON::Any
  is deprecated.  NOTE INCOMPATIBILITY: If you don't have JSON::MaybeXS
  installed, you'll need to install it before trying to install or update
  rem2html
- NEW FEATURE: Add a DO command.  This is just like INCLUDE, but relative
  paths are interpreted relative to the directory containing the current
  file.  That is:
    DO somefile.rem
  is equivalent to:
    INCLUDE [filedir()]/somefile.rem
- NEW FEATURE: Add the $DefaultTDelta system variable and associated
  - tt[N] command-line option to set a default time delta for timed
  reminder without an explicit +N delta.
- IMPROVEMENT: TkRemind: Store .tkremindrc in $XDG_CONFIG_HOME/tkremindrc
  or $HOME/.config/tkremindrc as per the XDG Base Directory Specification.
- BUG FIX: remind: Make the shell() built-in function respect
  $MaxStringLen
- BUG FIX: Use size_t to track the size of dynamic buffers rather than int.
  This permits Remind to read in files with lines longer than 1GB and to
  consume more than 1GB of output from the shell() command, both of which
  will surely be massively useful.  (The old limit was 1GB rather than 2GB
  because of details of the dynamic buffer resizing algorithm.)
* Thu Dec 30 2021 Detlef Steuer <detlef.steuer@gmx.de>
  * VERSION 3.3 Patch 11 - 2021-12-30
- IMPROVEMENT: TkRemind: Save the print dialog settings so they persist.
- IMPROVEMENT: TkRemind: Show queue in sorted order.
- IMPROVEMENT: TkRemind: Pass "-r" flag to inotifywait
- IMPROVEMENT: TkRemind: Draw moon phases with Tk canvas items rather than
  using PNG images.  This lets them change color along with other TkRemind
  preferences.
- IMPROVEMENT: TkRemind: Underline editable reminders when the pointer enters
  them; fire up the editor with either Button-1 or Button-3 for
  non-TkRemind-generated reminders.
- NEW FUNCTION: Remind: Add the isany() built-in function.
- IMPROVEMENT: rem2html: Add class names indicating number of rows in calendar
- IMPROVEMENT: remind: In -z0 mode, sleep with higher precision to ensure we
  wake as close to possible to each 1-minute boundary.
- IMPROVEMENT: rem2html: Coalesce table.rem-cal CSS into one block.  Thanks
  to Ian! D. Allen for pointing this out.
- IMPROVEMENT: examples/defs.rem: Modernize the examples and get rid of some
  cruft.
- CHANGE: Add $Latitude and $Longitude system variables.  Deprecate
  $LatDeg, $LatMin, $LatSec, $LongDeg, $LongMin and $LongSec.
- CHANGE: Test: Add "dump $" to test.rem.
* Tue Nov 30 2021 Detlef Steuer <detlef.steuer@gmx.de>
- Changes to remind
  * VERSION 3.3 Patch 10 - 2021-11-30
- IMPROVEMENT: TkRemind: Apply window and text colors to all GUI elements
  including buttons and status labels.
- NEW FEATURE: The new ADDOMIT keyword can shorten reminder files.
  The command:
    REM ...whatever... ADDOMIT MSG Foo
  behaves identically to:
    REM ...whatever... SATISFY 1
    IF trigvalid()
    OMIT [trigdate()] MSG Foo
    ENDIF
  For example, Labour Day can be displayed and omitted as follows:
    REM Mon 1 Sep SCANFROM -7 ADDOMIT MSG Labour Day
- UPDATE: Update contrib/remind-conf-mode to latest release
- CHANGE: The parser does not auto-convert numbers 90-99 to 1990-1999.  This
  was messing up things like "DURATION 90".  It also means you can no longer
  abbreviate the years 1990-1999 as 90-99.
- BUG FIX: Various documentation fixes
- BUG FIX: When switching users with the "-u" option, call initgroups()
  to properly set group membership list.
* Fri Oct 15 2021 Detlef Steuer <detlef.steuer@gmx.de>
- rem2html is included, cleanup of specfile
- CHANGES TO REMIND
  * VERSION 3.3 Patch 9 - 2021-10-14
- NEW FEATURE: Add "-+username" option to tell Remind to trust files owned by
  "username" and allow RUN directives in them.  Idea courtesy of Ian! D. Allen
- NEW FEATURE: Add "-u+username" variant to tell Remind to switch users to
  "username" without disabling RUN directives.  Idea courtesy of Ian! D. Allen
- CHANGE: rem2html: rem2html has been moved out of the www/ directory into
  its own rem2html/ directory.  If your system has the prerequisites
  (namely Perl, Getopt::Long and JSON::Any) then rem2html will be installed
  by "make install".
- CHANGE: Remove "cm2rem".  It was about 20 years obsolete.
- CHANGE: rem2html: Use inline data: URL images for moon images by default,
  thus producing a completely stand-alone HTML file.
- CHANGE: Remove unnecessary spaces from "remind -pp" JSON output.
- DOCUMENTATION FIX: Various man page fixes and tweaks.
- BUG FIX: rem2html: Tweak the default CSS stylesheet; more rational
  handling of rem2html command-line options.
- BUG FIX: remind: "remind -c" would sometimes highlight *two* days as
  "today"; this has been fixed.
- BUG FIX: Add a missing #ifdef...#endif and remove a C99-ism.  This once again
  allows Remind to be compiled with some very old C compilers.
* Tue Sep 14 2021 Detlef Steuer <detlef.steuer@gmx.de>
- CHANGES TO REMIND
  * VERSION 3.3 Patch 8 - 2021-09-13
- NEW FEATURE: remind: Add INCLUDECMD command
- NEW FEATURE: remind: Add shellescape() built-in function
- BUG FIX: tkremind: TkRemind would sometimes fill in incorrect initial
  values for the reminder-editing form if you clicked on a TkRemind-created
    reminder to edit it.  This has been fixed.
- BUG FIX: tkremind: Get back better error messages from Remind if you
  try to create a reminder with an invalid date specification.
- BUG FIX: remind: Catch integer overflow if we try to evaluate $IntMin * -1
- DOC UPDATES: remind: Minor man page fixes
* Tue May 11 2021 Detlef Steuer <detlef.steuer@gmx.de>
- CHANGES TO REMIND
  * VERSION 3.3 Patch 7 - 2021-05-10
- MINOR FIX: Refuse to run "make test" as root --- it would fail
  anyway with an obscure message.
- BUG FIX: Remind would sometimes compute incorrect trigger date for:
  REM Tue 29 Feb MSG ...
- BUG FIX: Remind would sometimes compute incorrect trigger date for
  a date spec like: Tue 31 2021 MSG ...
* Tue Mar 30 2021 Detlef Steuer <detlef.steuer@gmx.de>
- CHANGES TO REMIND
  * VERSION 3.3 Patch 6 - 2021-03-30
- test/test.rem: Change local to en_US.utf-8 only if current locale
  is not a UTF-8 locale.
- MINOR CHANGE: Remind's arithemtic operators (+, -, *, /) give errors
  on overflow rather than silently giving the wrong answer.
- MINOR CHANGE: Add $IntMin and $IntMax system variables.
- DOCUMENTATION FIX: Document that TkRemind now requires Tcl/Tk version
  8.5 or newer.
* Fri Jan 22 2021 Detlef Steuer <detlef.steuer@gmx.de>
- update to remind 3.3.5
- CHANGES TO REMIND
  * VERSION 3.3 Patch 5 - 2021-01-21
- NEW FEATURE: tkremind: Add ability to change fonts and colors from
  within TkRemind "Options" dialog.
- CHANGE: tkremind: TkRemind now requires Tcl/Tk 8.5 or newer.
- CHANGE: tkremind: You can specify the location of the options
  file on the command-line if you want to use one other than ~/.tkremindrc
- CLEANUP: tkremind: Remove "Apply Options" from Options dialog; we only
  need "Save Options".
- DOC FIX: Add missing release note in 3.3.4 notes regarding
  setpagedevice patch
- DOC FIX: tkremind: Document shortcut keys.
* Tue Jan 12 2021 Detlef Steuer <detlef.steuer@gmx.de>
- update to remind 3.3.4
- CHANGES TO REMIND
  * VERSION 3.3 Patch 4 - 2021-01-12
- NEW FEATURE: If "inotifywait" is installed, TkRemind uses it to refresh
  the calendar display right away when the reminders file/directory is updated.
  This makes TkRemind react almost instantly if external tools are editing
  or updating reminders.
- MINOR NEW FEATURE: rem2ps has a new '-x' option; this puts the day numbers
  on the top-left of the day's box instead of the top-right.
- MINOR FIXES: A typo in remind.1 was fixed; additional comments regarding
  UNTIL were added.
- BUG FIX: rem2ps: Call setpagedevice to set page size
  Based on a patch from Jonathan Kamens
* Mon Nov  9 2020 Detlef Steuer <detlef.steuer@gmx.de>
- update to remind 3.3.3
- CHANGES TO REMIND
  * VERSION 3.3 Patch 3 - 2020-11-09
- BUG FIX: Fix startup crash in TkRemind if "Show Today's Reminders on
  Startup" is enabled (which, unfortunately, is the default.)  Bug reported
  by Martin Ziemer.
* Sun Nov  8 2020 Detlef Steuer <detlef.steuer@gmx.de>
- update to remind 3.3.2
- CHANGES TO REMIND
  * VERSION 3.3 Patch 2 - 2020-11-08
- MINOR NEW FEATURE: Add MAYBE-UNCOMPUTABLE keyword; see the man page
  and discussion at
  https://dianne.skoll.ca/pipermail/remind-fans/2020/003745.html
- CHANGE: TkRemind always invokes Remind with the "-itkremind=1" option,
  even when printing.  NOTE INCOMPATIBILITY: This is a behavior change!
  When you print from TkRemind, we also invoke Remind with "-itkprint=1"
  so you can detect that PostScript is being generated.
- CHANGE: The maxmimum length of a variable name has been increased from
  16 characters to 64 characters.  Modern computers have plenty of memory.
- BUG FIXES: Minor documentation updates, typo fixes, clarifications, etc.
- BUG FIX: Fix calendar-drawing alignment errors when displaying UTF-8
  strings with zero-width combining characters and strings with tabs.
- BUG FIX: TkRemind would mess up placement of the WEEK special if invoked
  with the "-m" option.  This has been fixed.
- BUG FIX: TkRemind would sometimes fail with an error message when editing
  a reminder; this is because it was interpreting months 08 and 09 as
  illegal octal numbers.  This has been fixed.
* Fri Mar 20 2020 Detlef Steuer <detlef.steuer@gmx.de>
- update to remind 3.3.1
- CHANGE: For overlapping multi-day events, issue a reminder for the
  most *recent* event rather than the earliest event.  NOTE
  INCOMPATIBILITY: This is a behavior change!
- CHANGE: Do not convert 90-99 to 1990-1999 when parsing numbers to
  recognize years.  NOTE INCOMPATIBILITY: This is a behavior change!
- CHANGE: Revert change to -y option that included filename and line
  number in the hash.
- CHANGE: Retain newlines (produced by %%_) in JSON output.
- FIX: Document $FormWidth system variable
- FIX: Highlight today's date in "remind -c" output
- FIX: Eliminate compiler warnings on Ubuntu 18.04.
- IMPROVEMENT: Allow times to be specified either in 24-hour mode
  (HH:MM or HH.MM) or AM/PM mode (HH:MMam; HH:MMpm, etc.)
- IMPROVEMENT: Allow DURATION to be specified as a time (1:30) or a
  number of minutes (90).
- IMPROVEMENT: If terminal size can be determined, set $FormWidth to
  terminal width - 8; if not, set $FormWidth to 72.
- MINOR IMPROVEMENT: Add the "ampm()" built-in function.
* Sat Feb  1 2020 Detlef Steuer <detlef.steuer@gmx.de>
- update to remind-3.3.0
- FIX: rem2ps: Add a %%%%PageBoundingBox: document structuring convention
  comment.
- FIX: rem2ps: Ignore unknown SPECIAL-type reminders.
- IMPROVEMENT: In calendar mode ("-c" option), Remind automatically adjusts
  the width of the calendar to fit the terminal window if standard output
  is a TTY.
- IMPROVEMENT: Add JSON-based output with "remind -pp" and "remind -ppp"
  The JSON-based intermediate format preserves a lot more information
  about the original reminder, allowing back-ends more insight into
  the intent of the reminder, the recurrence used, etc.  See the documentation
  in "man rem2ps"
- IMPROVEMENT: TkRemind can "reverse-engineer" reminders that it creates
  using the additional information in the "remind -pp" format, so it
  doesn't create or use ugly comment blocks to delimit the reminders
  it creates.
- IMPROVEMENT: TkRemind: Add popup help to most buttons and controls.
- NEW FEATURE: Add support for $DefaultColor system variable, suggested
  by Tim Chase.
- NEW FEATURE: The "-@[n][,m]" command-line option allows colored reminders
  in Agenda Mode as well as in Calendar Mode.  It also adds support for
  terminal emulators that can handle the xterm 256-color escape sequences
  as well as the true 24-bit color escape sequences.
- CHANGE: SPECIALs are now case-insensitive.  Before, only SPECIAL COLOR
  would work.  Now you can use Special Color, special color, etc.
* Sat Jan  4 2020 Detlef Steuer <detlef.steuer@gmx.de>
- defattr still needed to support SLE11-SP4
* Sat Jan  4 2020 Detlef Steuer <detlef.steuer@gmx.de>
- update to remind-3.2.0
- removed buildroot and defattr calls from spec. No londer needed.
- IMPROVEMENT: Add support for events spanning multiple days (with AT
  and DURATION).  Add trigeventstart() and trigeventduration()
  introspection functions; see "MULTI-DAY EVENTS" in the man page.
- IMPROVEMENT: Add introspection functions trigback(), trigdelta(),
  trigduration(), trigfrom(), trigpriority(), trigrep(),
  trigscanfrom(), trigtimedelta(), trigtimerep(), and triguntil().  See
  man page for details; thanks to Tim Chase for the suggestion.
- IMPROVEMENT: TkRemind: Use PNG images for the next month / previous
  month buttons rather than -> and <-.  Also use nice anti-aliased
  moon phase images instead of ugly blocky bitmaps.
- CHANGE: Modify addition so that previously-illegal combinations
  TIME + TIME, TIME + DATETIME and DATETIME + TIME are now allowed.
  Also allow DATETIME - TIME.  If t1 and t2 are expressions of type TIME
  and dt is an expression of type DATETIME, then the following are now
  equivalent (before, the expressions on the left-hand side would fail
  with a "Type mismatch" error.)
  t1 + t2     ==     t1                + coerce("INT", t2)
  dt + t2     ==     dt                + coerce("INT", t2)
  t1 + dt     ==     coerce("INT", t1) + dt
  dt - t2     ==     dt                - coerce("INT", t2)
- DOC FIX: Document previously-undocumented $MaxStringLen system variable
- DOC FIX: Various minor documentation fixes.
- BUG FIX: Specifying a DURATION without an AT clause results in an error.
  Before, it would be accepted but not do anything useful.
- BUG FIX: Catch potential date overflow in slide() function
- BUG FIX: Fix compile error when compiling Romanian version; eliminate
  compiler warning when compiling non-English versions.
- BUG FIX: TkRemind: Fix startup failure of TkRemind if options are at
  default. :(
* Fri Aug 14 2015 puzel@suse.com
- update to remind-3.1.15
  - BUG FIX: Fix a buffer overflow found by Alexander Keller
    (CVE-2015-5957)
  - BUG FIX: Make parser reject an AT followed by more than one time.
  - BUG FIX: Make parser reject repeated delta or *repeat values.
  - NEW FEATURE: Putting the line __EOF__ in a .rem file causes
    Remind to treat it as end-of-file.
  - IMPROVEMENT: Use better PNG images for moons in the HTML display
  - BUG FIX: The "-n" command-line option should really run in
    "ADVANCE_MODE" rather than "CAL_MODE" internally; otherwise,
    the substitution sequences may be misinterpreted.
  - BUG FIX: A typo in clearing out MD5 sum context has been fixed.
  - BUG FIX: Typo in Spanish translation was fixed.
* Mon Apr 22 2013 puzel@suse.com
- update to remind-3.1.13
  - BUG FIX: Sunrise/Sunset calculations greatly improved thanks to
    John McGowan.  Accuracy should now be within a couple of
    minutes in most places.
  - BUG FIX: Allow specification of margins as low as 0 points in
    rem2ps, courtesy of Jonathan Kamens.
  - BUG FIX: Permit compilation with gcc 2.95 (which doesn't allow
    variable declarations after non-declaration statements in a
    block.)
  - BUG FIX: Several minor documentation errors corrected courtesy
    of Simon Ruderich.
  - BUG FIX: Spurious test harness failure was fixed.
* Tue Feb 28 2012 puzel@suse.com
- update to remind-3.1.12
  - NEW FEATURE: Many substitution sequences "%%x" have an alternate
    mode denoted by "%%*x".  This alternate mode leaves out
    prepositions.  For example, in English "%%i" might yield "on
    01-25" while "%%*i" yields only "01-25".
  - BUG FIX: The "dusk" and "dawn" calculations were completely
    wrong.  They have been fixed.  Also, sunrise/sunset calculations
    have been tweaked, so the results may be off by a minute or two
    compared to previous versions of Remind.
  - BUG FIX: For some inexplicable reason, dawn was considered to
    happen when the sun was 14 degrees below the horizon instead of
    the standard 6 degrees for Civil Dawn.  This has been fixed.
  - BUG FIXES: Clarified the man pages and fixed some typos.
  - BUG FIX: Add THROUGH to the remind.vim syntax highlighting file.
  - ENHANCEMENT (?): Allow SPECIAL COLOR to be spelled SPECIAL
    COLOUR.
  - BUG FIX: Apply minor Debian cleanups reported by Kurt B. Kaiser.
* Mon Feb 20 2012 mrdocs@opensuse.org
- disable make check - it breaks the build
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Dec 22 2010 puzel@novell.com
- clean up specfile
- enable 'make check' again
* Tue Nov  2 2010 puzel@novell.com
- update to remind-3.1.10
  - add the THROUGH keyword.  You can omit blocks of dates
    with: OMIT start THROUGH end
  - add support for multibyte characters (eg, UTF-8) in calendar
    output. Note that UTF-8 strings are still not supported in
    PostScript output.
  - add support for UTF-8 line-drawing characters in calendar
    output
  - you can have multiple TAG clauses in a REM statement
  - avoid spawning long-running background processes in "make
    test"
  - don't declare variables in the middle of statements (old C
    compilers choke.)
* Mon Jun 21 2010 puzel@novell.com
- update to remind-3.1.9
  - New "purge mode" to delete expired reminders. See
    the PURGE MODE section of the remind man page.
  - Support DURATION in TkRemind. Thanks to Marek Marczykowski.
  - Don't change the order of PS and PSFILE reminders.  Bug found
    by John McGowan.
  - "REM 1990-01-01 SATISFY 1" would yield a spurious parse error
    in earlier versions of Remind.
  - Yom HaShoah is moved to Thursday if it would normally fall on
    a Friday. Thanks to Jonathan Kamens for pointing this out.
* Wed Mar 10 2010 puzel@novell.com
- update to remind-3.1.8
  - Add the $T, $Td, $Tm, $Tw, $Ty, $U, $Ud, $Um, $Uw, $Uy
    special variables to make reminder files less wordy. See man page
    for details.
  - Ignore msgprefix() and msgsuffix() on RUN-type reminders.
  - Adjust Remind and Rem2PS so that SHADE specials don't obliterate
    earlier MOON specials.
  - Fix bug in SCHED calculations if Remind is started in the middle
    of a SCHED interval.
* Fri Jan 22 2010 puzel@novell.com
- initial package for Contrib, based on obs://home:code933k/remind
